==> aws-xray-sdk-postgres-1.1.0.tgz: package/README.md <==

## Requirements

  AWS X-Ray SDK Core
  Postgres 6.1.0 or greater

## AWS X-Ray and Postgres

AWS X-Ray Postgres package automatically records query information, request and response data.
Simply patch the Postgres package via 'capturePostgres' as seen below.

The AWS X-Ray SDK Core has two modes - 'manual' and 'automatic'.
Automatic mode uses the Continuation Local Storage package (CLS) and automatically keeps track of the current segment and subsegment. This is the default mode.
Manual mode requires you pass around the segment reference. See examples below.

### environment variables

    POSTGRES_DATABASE_VERSION        Sets additional data for the sql subsegment.
    POSTGRES_DRIVER_VERSION          Sets additional data for the sql subsegment.

### Automatic mode example

    var AWSXRay = require('aws-xray-sdk-core');
    var capturePostgres = require('aws-xray-sdk-postgres');

    var pg = capturePostgres(require('pg'));

    ...

    var client = new pg.Client();

    client.connect(function (err) {
      ...

      client.query({name: 'moop', text: 'SELECT $1::text as name'}, ['brianc'], function (err, result) {
        //automatically captures query information and error (if any)
      });
    });

    ...

    var pool = new pg.Pool(config);
    pool.connect(function(err, client, done) {
      if(err) {
        return console.error('error fetching client from pool', err);
      }
      var query = client.query('SELECT * FROM mytable', function(err, result) {
        //automatically captures query information and error (if any)
      });
    });

### Manual mode example

    var AWSXRay = require('aws-xray-sdk-core');
    var capturePostgres = require('aws-xray-sdk-postgres');

    var pg = capturePostgres(require('pg'));

    ...

    var client = new pg.Client();

    client.connect(function (err) {
      ...

      client.query({name: 'moop', text: 'SELECT $1::text as name'}, ['mcmuls'], function (err, result) {
        //automatically captures query information and error (if any)
      });
    });

    ...

    var pool = new pg.Pool(config);
    pool.connect(function(err, client, done) {
      if(err) {
        return console.error('error fetching client from pool', err);
      }
      var query = client.query('SELECT * FROM mytable', function(err, result) {
        //automatically captures query information and error (if any)
      }, segment));
    };

==> aws-xray-sdk-postgres-1.3.0.tgz: package/README.md <==

## Requirements

  AWS X-Ray SDK Core
  Postgres 6.1.0 or greater

## AWS X-Ray and Postgres

The AWS X-Ray Postgres package automatically records query information and request
and response data. Simply patch the Postgres package via `capturePostgres` as shown below.

The AWS X-Ray SDK Core has two modes - `manual` and `automatic`.
Automatic mode uses the Continuation Local Storage package (CLS) and automatically
tracks the current segment and subsegment. This is the default mode.
Manual mode requires that you pass around the segment reference. See the examples below.

### Environment variables

    POSTGRES_DATABASE_VERSION        Sets additional data for the sql subsegment.
    POSTGRES_DRIVER_VERSION          Sets additional data for the sql subsegment.

### Automatic mode example

    var AWSXRay = require('aws-xray-sdk-core');
    var capturePostgres = require('aws-xray-sdk-postgres');

    var pg = capturePostgres(require('pg'));

    ...

    var client = new pg.Client();

    client.connect(function (err) {
      ...

      client.query({name: 'moop', text: 'SELECT $1::text as name'}, ['brianc'], function (err, result) {
        //Automatically captures query information and errors (if any)
      });
    });

    ...

    var pool = new pg.Pool(config);
    pool.connect(function(err, client, done) {
      if(err) {
        return console.error('error fetching client from pool', err);
      }
      var query = client.query('SELECT * FROM mytable', function(err, result) {
        //Automatically captures query information and errors (if any)
      });
    });

### Manual mode example

    var AWSXRay = require('aws-xray-sdk-core');
    var capturePostgres = require('aws-xray-sdk-postgres');

    var pg = capturePostgres(require('pg'));

    ...

    var client = new pg.Client();

    client.connect(function (err) {
      ...

      client.query({name: 'moop', text: 'SELECT $1::text as name'}, ['mcmuls'], function (err, result) {
        //Automatically captures query information and errors (if any)
      });
    });

    ...

    var pool = new pg.Pool(config);
    pool.connect(function(err, client, done) {
      if(err) {
        return console.error('error fetching client from pool', err);
      }
      var query = client.query('SELECT * FROM mytable', function(err, result) {
        //Automatically captures query information and errors (if any)
      }, segment));
    };
